@@ -9,7 +9,7 @@
 #' @param spin logical for whether or not to use the shortest probability interval or the central interval.
 #' @param ci numeric confidence interval measure.
 #' 
-#' @importFrom plyr ddply mutate
+#' @importFrom plyr ddply
 #' @keywords internals
 #' @noRd
 
@@ -45,17 +45,43 @@ IntervalConstrict <- function(Simb = Simb, SubVar = SubVar, qi = qi, QI = QI, sp
 	{
 		Bottom <- (1 - ci)/2
 		Top <- 1 - Bottom
-		SimbPerc <- eval(parse(text = paste0("ddply(Simb, SubVar, mutate, Lower = QI < quantile(QI,", Bottom, "))")))
-		SimbPerc <- eval(parse(text = paste0("ddply(SimbPerc, SubVar, mutate, Upper = QI > quantile(QI,", Top, "))" )))
+		SimbPerc <- eval(parse(text = paste0("ddply(Simb, SubVar, transform, Lower = QI < quantile(QI,", Bottom, ", na.rm = TRUE))")))
+		SimbPerc <- eval(parse(text = paste0("ddply(SimbPerc, SubVar, transform, Upper = QI > quantile(QI,", Top, ", na.rm = TRUE))" )))
 	}
 
 	# Drop simulations outside of the shortest probability interval
 	else if (isTRUE(spin))
 	{
-		SimbPerc <- eval(parse(text = paste0("ddply(Simb, SubVar, mutate, Lower = QI < simPH:::SpinBounds(QI, conf = ", ci, ", lb = ", lb, ", LowUp = 1))" )))
-		SimbPerc <- eval(parse(text = paste0("ddply(SimbPerc, SubVar, mutate, Upper = QI > simPH:::SpinBounds(QI, conf = ", ci, ", lb = ", lb, ", LowUp = 2))" )))
+		SimbPerc <- eval(parse(text = paste0("ddply(Simb, SubVar, transform, Lower = QI < simPH:::SpinBounds(QI, conf = ", ci, ", lb = ", lb, ", LowUp = 1))" )))
+		SimbPerc <- eval(parse(text = paste0("ddply(SimbPerc, SubVar, transform, Upper = QI > simPH:::SpinBounds(QI, conf = ", ci, ", lb = ", lb, ", LowUp = 2))" )))
 	}
 
 	SimbPerc <- subset(SimbPerc, Lower == FALSE & Upper == FALSE)
 	return(SimbPerc)
-}
\ No newline at end of file
+}
+
+#' Drop any individual simulation with at least one value outside of the specified confidence bounds 
+#'
+#' @param SimIn data frame
+#'
+#' @importFrom dplyr group_by
+#' @importFrom dplyr mutate
+#'
+#' @keywords internals
+#' @noRd
+
+OutlierDrop <- function(SimIn){
+    # CRAN nonsense
+    SimID <- dummy <- Rows <- NULL 
+    
+    # Drop simulations that do not have all values within
+    # the central interval
+    SimIn$dummy <- 1
+    Sims <- dplyr::group_by(SimIn, SimID) 
+    Sims <- dplyr::mutate(Sims, Rows = sum(dummy))
+    MaxRows <- max(Sims$Rows)
+    Sims <- as.data.frame(Sims)
+    Sims <- subset(Sims, Rows == MaxRows)
+    Sims
+}
+
