@@ -7,17 +7,17 @@
 #' @param qi quantity of interest to simulate. Values can be \code{"Marginal Effect"}, \code{"First Difference"}, \code{"Hazard Ratio"}, and \code{"Hazard Rate"}. The default is \code{qi = "Hazard Ratio"}. If \code{qi = "Hazard Rate"} and the \code{coxph} model has strata, then hazard rates for each strata will also be calculated.
 #' @param X1 numeric vector of fitted values of \code{b1} to simulate for. If \code{qi = "Marginal Effect"} then only \code{X2} can be set. If you want to plot the results, \code{X1} should have more than one value.
 #' @param X2 numeric vector of fitted values of \code{b2} to simulate for. 
-#' @param means logical, whether or not to use the mean values to fit the hazard rate for covaraiates other than \code{b1} \code{b2} and \code{b1*b2}. Note: it does not currently support models that include polynomials created by \code{\link{I}}.i
+#' @param means logical, whether or not to use the mean values to fit the hazard rate for covaraiates other than \code{b1} \code{b2} and \code{b1*b2}. Note: it does not currently support models that include polynomials created by \code{\link{I}}. Note: EXPERIMENTAL. \code{lines} are not currently supported in \code{\link{simGG}} if \code{means = TRUE}.
 #' @param expMarg logical. Whether or not to exponentiate the marginal effect.
 #' @param nsim the number of simulations to run per value of X. Default is \code{nsim = 1000}.
 #' @param ci the proportion of middle simulations to keep. The default is \code{ci = 0.95}, i.e. keep the middle 95 percent. If \code{spin = TRUE} then \code{ci} is the confidence level of the shortest probability interval. Any value from 0 through 1 may be used.
 #' @param spin logical, whether or not to keep only the shortest probability interval rather than the middle simulations. Currently not supported for hazard rates.
 #'
 #' @details Simulates marginal effects, first differences, hazard ratios, and hazard rates for linear multiplicative interactions. 
-#' Marginal effects are calculated as in Brambor et al. (2006) with the addition that we take the exponent, so that it resembles a hazard ratio. You choose not to take the exponent by setting the argument \code{expMarg = FALSE}. For an interaction between variables \eqn{X} and \eqn{Z} then the marginal effect for \eqn{X} is:
-#' \deqn{ME_{X} = exp(\beta_{X} + \beta_{XZ}Z).}
+#' Marginal effects are calculated as in Brambor et al. (2006) with the addition that we take the exponent, so that it resembles a hazard ratio. You can choose not to take the exponent by setting the argument \code{expMarg = FALSE}. For an interaction between variables \eqn{X} and \eqn{Z} the marginal effect for \eqn{X} is:
+#' \deqn{ME_{X} = e^(\beta_{X} + \beta_{XZ}Z)}{ME[X] = exp(\beta[X] + \beta[XZ]Z)}
 #'
-#' Note that for First Differences the comparison is not between two values of the same variable but two values of the constitute variable and 0.
+#' Note that for First Differences the comparison is not between two values of the same variable but two values of the constitute variable and 0 for the two variables.
 #'
 #' @examples 
 #' # Load Carpenter (2002) data
@@ -27,20 +27,22 @@
 #' library(survival)
 #'
 #' # Run basic model
-#' M1 <- coxph(Surv(acttime, censor) ~ lethal*prevgenx, data = CarpenterFdaData)
+#' M1 <- coxph(Surv(acttime, censor) ~ lethal*prevgenx, 
+#'             data = CarpenterFdaData)
 #' 
-#' # Simulate Marginal Effect of lethal for multiple values of prevgenx
+#' # Simulate Marginal Effect of lethal for multiple 
+#' # values of prevgenx
 #' Sim1 <- coxsimInteract(M1, b1 = "lethal", b2 = "prevgenx",
-#'						  X2 = seq(2, 115, by = 2), spin = TRUE)
+#'                        X2 = seq(2, 115, by = 2), spin = TRUE)
 #'
 #' ## dontrun
 #' # Change the order of the covariates to make a more easily
 #' # interpretable relative hazard graph. 
 #' # M2 <- coxph(Surv(acttime, censor) ~ prevgenx*lethal + 
-#' #             orphdum,
-#' #             data = CarpenterFdaData)
+#' #             orphdum, data = CarpenterFdaData)
 #'
-#' # Simulate Hazard Ratio of lethal for multiple values of prevgenx
+#' # Simulate Hazard Ratio of lethal for multiple 
+#' # values of prevgenx
 #' # Sim2 <- coxsimInteract(M2, b1 = "prevgenx", b2 = "lethal", 
 #' #                    X1 = seq(2, 115, by = 2),
 #' #                    X2 = c(0, 1),
@@ -68,14 +70,13 @@
 #' @return a \code{siminteract} class object
 #' @import data.table
 #' @importFrom reshape2 melt
-#' @importFrom plyr ddply mutate
 #' @importFrom survival basehaz
-#' @importFrom MSBVAR rmultnorm
+#' @importFrom MASS mvrnorm
 #' @export
 
 coxsimInteract <- function(obj, b1, b2, qi = "Marginal Effect", X1 = NULL, X2 = NULL, means = FALSE, expMarg = TRUE, nsim = 1000, ci = 0.95, spin = FALSE)
 {
-	HRValue <- strata <- QI <- NULL
+	HRValue <- strata <- QI <- SimID <- NULL
 	if (qi != "Hazard Rate" & isTRUE(means)){
 		stop("means can only be TRUE when qi = 'Hazard Rate'.")
 	}
@@ -94,12 +95,15 @@ coxsimInteract <- function(obj, b1, b2, qi = "Marginal Effect", X1 = NULL, X2 =
 		MeansMessage <- TRUE
 	}
 
+    # Create simulation ID variable
+    SimID <- 1:nsim
+
 	# Parameter estimates & Variance/Covariance matrix
 	Coef <- matrix(obj$coefficients)
 	VC <- vcov(obj)
 	
 	# Draw covariate estimates from the multivariate normal distribution	    
-	Drawn <- rmultnorm(n = nsim, mu = Coef, vmat = VC)
+	Drawn <- mvrnorm(n = nsim, mu = Coef, Sigma = VC)
 	DrawnDF <- data.frame(Drawn)
 	dfn <- names(DrawnDF)
 
@@ -113,7 +117,7 @@ coxsimInteract <- function(obj, b1, b2, qi = "Marginal Effect", X1 = NULL, X2 =
 	if (!isTRUE(means)){
 
 		# Subset data frame to only include interaction constitutive terms and
-		Simb <- data.frame(Drawn[, NamesInt])
+		Simb <- data.frame(SimID, Drawn[, NamesInt])
 
 		# Find quantity of interest
 		if (qi == "Marginal Effect"){
@@ -124,10 +128,10 @@ coxsimInteract <- function(obj, b1, b2, qi = "Marginal Effect", X1 = NULL, X2 =
 				names(X2df) <- c("X2")
 				Simb <- merge(Simb, X2df)
         if (isTRUE(expMarg)){
-				  Simb$QI <- exp(Simb[, 1] + (Simb[, 3] * Simb[, 4])) 
+				  Simb$QI <- exp(Simb[, 2] + (Simb[, 4] * Simb[, 5])) 
         }
         else if (!isTRUE(expMarg)){
-          Simb$QI <- Simb[, 1] + (Simb[, 3] * Simb[, 4])
+          Simb$QI <- Simb[, 2] + (Simb[, 4] * Simb[, 5])
         }
 			}
 		}
@@ -139,7 +143,7 @@ coxsimInteract <- function(obj, b1, b2, qi = "Marginal Effect", X1 = NULL, X2 =
 			names(Xs) <- c("X1", "X2")
 			Xs$Comparison <- paste0(Xs[, 1], ", ", Xs[, 2])
 		    Simb <- merge(Simb, Xs)
-			Simb$QI <- (exp((Simb$X1 * Simb[, 1]) + (Simb$X2 * Simb[, 2]) + (Simb$X1 * Simb$X2 * Simb[, 3]) - 1) * 100)	
+			Simb$QI <- (exp((Simb$X1 * Simb[, 2]) + (Simb$X2 * Simb[, 3]) + (Simb$X1 * Simb$X2 * Simb[, 4]) - 1) * 100)	
 		  }
 		}
 		else if (qi == "Hazard Ratio"){
@@ -150,7 +154,7 @@ coxsimInteract <- function(obj, b1, b2, qi = "Marginal Effect", X1 = NULL, X2 =
 			names(Xs) <- c("X1", "X2")
 			Xs$Comparison <- paste0(Xs[, 1], ", ", Xs[, 2])
 		    Simb <- merge(Simb, Xs)
-			Simb$QI <- (exp((Simb$X1 * Simb[, 1]) + (Simb$X2 * Simb[, 2]) + (Simb$X1 * Simb$X2 * Simb[, 3])))
+			Simb$QI <- (exp((Simb$X1 * Simb[, 2]) + (Simb$X2 * Simb[, 3]) + (Simb$X1 * Simb$X2 * Simb[, 4])))
 		  }
 		}
 		else if (qi == "Hazard Rate"){
@@ -163,8 +167,8 @@ coxsimInteract <- function(obj, b1, b2, qi = "Marginal Effect", X1 = NULL, X2 =
 			Xs <- data.frame(X1, X2)
 			Xs$HRValue <- paste0(Xs$X1, ", ", Xs$X2)
 		   
-		    Simb <- merge(Simb, Xs)
-			Simb$HR <- exp((Simb$X1 * Simb[, 1]) + (Simb$X2 * Simb[, 2]) + (Simb$X1 * Simb$X2 * Simb[, 3]))	 
+            Simb <- merge(Simb, Xs)
+			Simb$HR <- exp((Simb$X1 * Simb[, 2]) + (Simb$X2 * Simb[, 3]) + (Simb$X1 * Simb$X2 * Simb[, 4]))	 
 		  	
 		  	bfit <- basehaz(obj)
 		  	bfit$FakeID <- 1
@@ -179,9 +183,9 @@ coxsimInteract <- function(obj, b1, b2, qi = "Marginal Effect", X1 = NULL, X2 =
 	        }
 	        Simb$QI <- Simb$hazard * Simb$HR 
 	        if (is.null(Simb$strata)){
-	          Simb <- Simb[, list(time, QI, HRValue)]
+	          Simb <- Simb[, list(SimID, time, QI, HRValue)]
 	        } else if (!is.null(Simb$strata)){
-	          Simb <- Simb[, list(time, QI, HRValue, strata)]
+	          Simb <- Simb[, list(SimID, time, QI, HRValue, strata)]
 	        }
 	        Simb <- data.frame(Simb)
 			}
@@ -261,31 +265,51 @@ coxsimInteract <- function(obj, b1, b2, qi = "Marginal Effect", X1 = NULL, X2 =
 	}
 
 	# Drop simulations outside of the middle
-	SimbPerc <- IntervalConstrict(Simb = Simb, SubVar = SubVar, qi = qi,
-									QI = QI, spin = spin, ci = ci)	
+	SimbPerc <- IntervalConstrict(Simb = Simb, SubVar = SubVar, 
+		                qi = qi, QI = QI, spin = spin, ci = ci)	
 
 	# Final clean up
-	if (qi == "Hazard Rate"){
-		colour <- NULL
+	if (qi == "Hazard Rate" & !isTRUE(means)){
 		if (is.null(obj$strata)){
-			SimbPercSub <- data.frame(SimbPerc$time, SimbPerc$QI, SimbPerc$HRValue)
-			names(SimbPercSub) <- c("Time", "HRate", "HRValue")
+			SimbPercSub <- data.frame(SimbPerc$SimID, 
+				                      SimbPerc$time, SimbPerc$QI,
+				                      SimbPerc$HRValue)
+			names(SimbPercSub) <- c("SimID", "Time", "HRate", 
+				                    "HRValue")
 		} else if (!is.null(SimbPerc$strata)) {
-		SimbPercSub <- data.frame(SimbPerc$time, SimbPerc$QI, SimbPerc$strata, SimbPerc$HRValue)
-		names(SimbPercSub) <- c("Time", "HRate", "Strata", "HRValue")
+		SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$time, 
+		                SimbPerc$QI, SimbPerc$strata, 
+		                SimbPerc$HRValue)
+		names(SimbPercSub) <- c("SimID", "Time", "HRate", 
+			                    "Strata", "HRValue")
+		}
+	} else if (qi == "Hazard Rate" & isTRUE(means)){
+		if (is.null(obj$strata)){
+			SimbPercSub <- data.frame(SimbPerc$time, SimbPerc$QI,
+				                      SimbPerc$HRValue)
+			names(SimbPercSub) <- c("Time", "HRate", 
+				                    "HRValue")
+		} else if (!is.null(SimbPerc$strata)) {
+		SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$time, 
+		                SimbPerc$QI, SimbPerc$strata, 
+		                SimbPerc$HRValue)
+		names(SimbPercSub) <- c("SimID", "Time", "HRate", 
+			                    "Strata", "HRValue")
 		}
 	} else if (qi == "Hazard Ratio"){
-		colour <- NULL
-	  	SimbPercSub <- data.frame(SimbPerc$X1, SimbPerc$X2, SimbPerc$QI, SimbPerc$Comparison)
-	  	names(SimbPercSub) <- c("X1", "X2", "QI", "Comparison")
+	  	SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$X1, SimbPerc$X2, SimbPerc$QI, SimbPerc$Comparison)
+	  	names(SimbPercSub) <- c("SimID", "X1", "X2", "QI", 
+	  		                    "Comparison")
 	} else if (qi == "Marginal Effect"){
 	  	spalette <- NULL
-	  	SimbPercSub <- data.frame(SimbPerc$X2, SimbPerc$QI)
-	  	names(SimbPercSub) <- c("X2", "QI")
+	  	SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$X2,
+	  	                          SimbPerc$QI)
+	  	names(SimbPercSub) <- c("SimID", "X2", "QI")
 	} else if (qi == "First Difference"){
 		colour <- NULL
-		SimbPercSub <- data.frame(SimbPerc$X1, SimbPerc$X2, SimbPerc$QI)
-		names(SimbPercSub) <- c("X1", "X2", "QI")
+		SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$X1,
+		                          SimbPerc$X2, SimbPerc$QI)
+		names(SimbPercSub) <- c("SimID", "X1", "X2", "QI")
 	}
 	class(SimbPercSub) <- c("siminteract", qi)
 	SimbPercSub
