@@ -1,6 +1,6 @@
-#' Simulate time-varying quantities of interest from Cox Proportional Hazards models
+#' Simulate time-interactive quantities of interest from Cox Proportional Hazards models
 #' 
-#' \code{coxsimtvc} simulates time-varying relative hazards, first differences, and hazard ratios from models estimated with \code{\link{coxph}} using the multivariate normal distribution. These can be plotted with \code{\link{simGG}}.
+#' \code{coxsimtvc} simulates time-interactive relative hazards, first differences, and hazard ratios from models estimated with \code{\link{coxph}} using the multivariate normal distribution. These can be plotted with \code{\link{simGG}}.
 #' @param obj a \code{\link{coxph}} fitted model object with a time interaction. 
 #' @param b the non-time interacted variable's name.
 #' @param btvc the time interacted variable's name.
@@ -21,19 +21,19 @@
 #' @details Simulates time-varying relative hazards, first differences, and hazard ratios using parameter estimates from \code{coxph} models. Can also simulate hazard rates for multiple strata.
 #'
 #' Relative hazards are found using:
-#' \deqn{RH = e^{\beta_{1} + \beta_{2}f(t)}}
+#' \deqn{RH = e^{\beta_{1} + \beta_{2}f(t)}}{RH = exp(\beta[1] + \beta[2] f(t))}
 #' where \eqn{f(t)} is the function of time.
 #'
 #' First differences are found using:
-#' \deqn{FD = (e^{(X_{j} - X_{l}) (\beta_{1} + \beta_{2}f(t))} - 1) * 100}
-#' where \eqn{X_{j}} and \eqn{X_{l}} are some values of \eqn{X} to contrast.
+#' \deqn{FD = (e^{(X_{j} - X_{l}) (\beta_{1} + \beta_{2}f(t))} - 1) * 100}{FD = (exp((X[j] - X[l])(\beta[1] + \beta[2]f(t)) - 1) * 100}
+#' where \eqn{X_{j}}{X[j]} and \eqn{X_{l}}{X[l]} are some values of \eqn{X} to contrast.
 #'
 #' Hazard ratios are calculated using:
-#' \deqn{FD = e^{(X_{j} - X_{l}) (\beta_{1} + \beta_{2}f(t))}}
-#' When simulating non-stratifed time-varying harzards \code{coxsimtvc} uses the point estimates for a given coefficient \eqn{\hat{\beta}_{x}} and its time interaction \eqn{\hat{\beta}_{xt}} along with the variance matrix (\eqn{\hat{V}(\hat{\beta})}) estimated from a \code{coxph} model. These are used to draw values of \eqn{\beta_{1}} and \eqn{\beta_{2}} from the multivariate normal distribution \eqn{N(\hat{\beta},\: \hat{V}(\hat{beta}))}.
+#' \deqn{FD = e^{(X_{j} - X_{l}) (\beta_{1} + \beta_{2}f(t))}}{FD = exp((X[j] - X[l])(\beta[1] + \beta[2]f(t))}
+#' When simulating non-stratifed time-varying harzards \code{coxsimtvc} uses the point estimates for a given coefficient \eqn{\hat{\beta}_{x}}{hat \beta[x]} and its time interaction \eqn{\hat{\beta}_{xt}}{hat \beta[xt]} along with the variance matrix (\eqn{\hat{V}(\hat{\beta})}{hat V(hat \beta)}) estimated from a \code{coxph} model. These are used to draw values of \eqn{\beta_{1}}{\beta[1]} and \eqn{\beta_{2}}{\beta[2]} from the multivariate normal distribution \eqn{N(\hat{\beta},\: \hat{V}(\hat{\beta}))}{N(hat \beta, hat V (hat \beta))}.
 #'
 #' When simulating stratified time-varying hazard rates \eqn{H} for a given strata \eqn{k}, \code{coxsimtvc} uses:
-#' \deqn{H_{kxt} = \hat{\beta_{k0t}}\exp{\hat{\beta_{1}} + \beta_{2}f(t)}}
+#' \deqn{H_{kxt} = \hat{\beta}_{k0t}e^{\hat{\beta_{1}} + \beta_{2}f(t)}}{H_{kxt} = hat \beta[k0t]exp(hat \beta[1] + \beta[2]f(t))}
 #' The resulting simulation values can be plotted using \code{\link{simGG}}. 
 #'
 #' @examples
@@ -45,7 +45,8 @@
 #' 
 #' # Create natural log time interactions
 #' Golubtvc <- function(x){
-#'   assign(paste0("l", x), tvc(GolubEUPData, b = x, tvar = "end", tfun = "log"))
+#'   assign(paste0("l", x), tvc(GolubEUPData, b = x, 
+#'          tvar = "end", tfun = "log"))
 #' }
 #' 
 #' GolubEUPData$Lcoop <-Golubtvc("coop")
@@ -90,7 +91,7 @@
 #' @import data.table
 #' @importFrom reshape2 melt
 #' @importFrom survival basehaz
-#' @importFrom MSBVAR rmultnorm
+#' @importFrom MASS mvrnorm
 #' @export
 #'
 #' @references Golub, Jonathan, and Bernard Steunenberg. 2007. ''How Time Affects EU Decision-Making.'' European Union Politics 8(4): 555-66.
@@ -134,12 +135,15 @@ coxsimtvc <- function(obj, b, btvc, qi = "Relative Hazard", Xj = NULL, Xl = NULL
     tf <- (seq(from = from, to = to, by = by))^pow
   }
 
+  # Create simulation ID variable
+  SimID <- 1:nsim
+
   # Parameter estimates & Varance/Covariance matrix
   Coef <- matrix(obj$coefficients)
   VC <- vcov(obj)
     
   # Draw values from the multivariate normal distribution
-  Drawn <- rmultnorm(n = nsim, mu = Coef, vmat = VC)
+  Drawn <- mvrnorm(n = nsim, mu = Coef, Sigma = VC)
   DrawnDF <- data.frame(Drawn)
   dfn <- names(DrawnDF)
  
@@ -148,18 +152,18 @@ coxsimtvc <- function(obj, b, btvc, qi = "Relative Hazard", Xj = NULL, Xl = NULL
   btvcpos <- match(btvc, dfn)
   
   Drawn <- data.frame(Drawn[, c(bpos, btvcpos)])
-  Drawn$ID <- 1:nsim
+  Drawn$SimID <- SimID
 
   # Multiply time function with btvc
   TVSim <- outer(Drawn[,2], tf)
   TVSim <- data.frame(melt(TVSim))
-  names(TVSim) <- c("ID", "time", "TVC")
+  names(TVSim) <- c("SimID", "time", "TVC")
   time <- 1:length(tf)
   TempDF <- data.frame(time, tf)
   TVSim <- merge(TVSim, TempDF)
 
   # Combine with non TVC version of the variable
-  TVSim <- merge(Drawn, TVSim, by = "ID")
+  TVSim <- merge(Drawn, TVSim, by = "SimID")
   TVSim$CombCoef <- TVSim[[2]] + TVSim$TVC
 
   # Find quantity of interest
@@ -208,9 +212,9 @@ coxsimtvc <- function(obj, b, btvc, qi = "Relative Hazard", Xj = NULL, Xl = NULL
       }
       Simb$QI <- Simb$hazard * Simb$HR 
       if (is.null(Simb$strata)){
-        Simb <- Simb[, list(time, tf, Xj, QI, HRValue)]
+        Simb <- Simb[, list(SimID, time, tf, Xj, QI, HRValue)]
       } else if (!is.null(Simb$strata)){
-        Simb <- Simb[, list(time, tf, Xj, QI, HRValue, strata)]
+        Simb <- Simb[, list(SimID, time, tf, Xj, QI, HRValue, strata)]
       }
       Simb <- data.frame(Simb)
   }
@@ -234,21 +238,21 @@ coxsimtvc <- function(obj, b, btvc, qi = "Relative Hazard", Xj = NULL, Xl = NULL
   # Subset simtvc object & create data frame of important variables
   if (qi == "Hazard Rate"){
     if (is.null(SimbPerc$strata)){
-      SimbPercSub <- data.frame(SimbPerc$RealTime, SimbPerc$QI, SimbPerc$HRValue)
-      names(SimbPercSub) <- c("Time", "HRate", "HRValue")
+      SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$RealTime, SimbPerc$QI, SimbPerc$HRValue)
+      names(SimbPercSub) <- c("SimID", "Time", "HRate", "HRValue")
     } else if (!is.null(SimbPerc$strata)) {
-      SimbPercSub <- data.frame(SimbPerc$RealTime, SimbPerc$QI, SimbPerc$strata, SimbPerc$HRValue)
-      names(SimbPercSub) <- c("Time", "HRate", "Strata", "HRValue")
+      SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$RealTime, SimbPerc$QI, SimbPerc$strata, SimbPerc$HRValue)
+      names(SimbPercSub) <- c("SimID", "Time", "HRate", "Strata", "HRValue")
     }
   } else if (qi == "Hazard Ratio"){
-      SimbPercSub <- data.frame(SimbPerc$RealTime, SimbPerc$QI, SimbPerc$Comparison)
-      names(SimbPercSub) <- c("Time", "QI", "Comparison")
+      SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$RealTime, SimbPerc$QI, SimbPerc$Comparison)
+      names(SimbPercSub) <- c("SimID", "Time", "QI", "Comparison")
   } else if (qi == "Relative Hazard"){
-      SimbPercSub <- data.frame(SimbPerc$RealTime, SimbPerc$QI, SimbPerc$Xj)
-      names(SimbPercSub) <- c("Time", "QI", "Xj")
+      SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$RealTime, SimbPerc$QI, SimbPerc$Xj)
+      names(SimbPercSub) <- c("SimID", "Time", "QI", "Xj")
   } else if (qi == "First Difference"){
-      SimbPercSub <- data.frame(SimbPerc$RealTime, SimbPerc$QI, SimbPerc$Comparison)
-      names(SimbPercSub) <- c("Time", "QI", "Comparison")
+      SimbPercSub <- data.frame(SimbPerc$SimID, SimbPerc$RealTime, SimbPerc$QI, SimbPerc$Comparison)
+      names(SimbPercSub) <- c("SimID", "Time", "QI", "Comparison")
   }
   class(SimbPercSub) <- c("simtvc", qi)
   SimbPercSub
