@@ -1,4 +1,4 @@
-#' Plot simulated time-varying hazard ratios or stratified time-varying hazard rates from Cox Proportional Hazards Models
+#' Plot simulated time-interactive hazard ratios or stratified time-interactive hazard rates from Cox Proportional Hazards Models
 #' 
 #' \code{simGG.simtvc} uses \link{ggplot2} to plot the simulated hazards from a \code{simtvc} class object created by \code{\link{coxsimtvc}} using \link{ggplot2}. 
 #' @param obj a \code{simtvc} class object
@@ -7,18 +7,18 @@
 #' @param xlab a label for the plot's x-axis.
 #' @param ylab a label of the plot's y-axis. The default uses the value of \code{qi}.
 #' @param title the plot's main title.
-#' @param smoother what type of smoothing line to use to summarize the plotted coefficient.
+#' @param smoother what type of smoothing line to use to summarize the center of the simulation distribution.
 #' @param spalette colour palette for when there are multiple sets of comparisons to plot. Default palette is \code{"Set1"}. See \code{\link{scale_colour_brewer}}.
 #' @param legend specifies what type of legend to include (if applicable). The default is \code{legend = "legend"}. To hide the legend use \code{legend = FALSE}. See the \code{\link{discrete_scale}} for more details.
 #' @param leg.name name of the legend (if applicable).
 #' @param lsize size of the smoothing line. Default is 1. See \code{\link{ggplot2}}.
 #' @param psize size of the plotted simulation points. Default is \code{psize = 1}. See \code{\link{ggplot2}}.
-#' @param alpha point alpha (e.g. transparency) for the points or ribbons. Default is \code{alpha = 0.1}. See \code{\link{ggplot2}}.
-#' @param ribbons logical specifies whether or not to use summary ribbons of the simulations rather than plotting every simulation value as a point. If \code{ribbons = TRUE} a plot will be created with shaded areas ('ribbons') for the minimum and maximum simulation values (i.e. the middle interval set with \code{qi} in \code{\link{coxsimtvc}}) as well as the central 50 percent of this area. It also plots a line for the median value of the full area, so values in \code{smoother} are ignored. One of the key advantages of using ribbons rather than points is that it creates plots with smaller file sizes.
+#' @param alpha numeric. Alpha (e.g. transparency) for the points, lines, or ribbons. Default is \code{alpha = 0.2}. See \code{\link{ggplot2}}. Note, if \code{type = "lines"} or \code{type = "points"} then \code{alpah} sets the maximum value per line or point at the center of the distribution. Lines or points further from the center are more transparent the further they get from the middle. 
+#' @param type character string. Specifies how to plot the simulations. Can be \code{points}, \code{lines}, or \code{ribbons}. If points then each simulation value will be plotted. If \code{lines} is chosen then each simulation is plotted using a different line. Note: any simulation with a value along its length that is outside of the specified central interval will be dropped. This is to create a smooth plot. If \code{type = "ribbons"} a plot will be created with shaded areas ('ribbons') for the minimum and maximum simulation values (i.e. the middle interval set with \code{qi} in \code{\link{coxsimSpline}}) as well as the central 50 percent of this area. It also plots a line for the median value of the full area, so values in \code{smoother} are ignored. One of the key advantages of using ribbons rather than points is that it creates plots with smaller file sizes.
 #' @param ... Additional arguments. (Currently ignored.)
 #'
 #' @return a \code{gg} \code{ggplot} class object
-#' @details Plots either a time varying hazard ratio or the hazard rates for multiple strata. Currently the strata legend labels need to be changed manually (see \code{\link{revalue}} in the \link{plyr} package) in the \code{simtvc} object with the \code{strata} component. Also, currently the x-axis tick marks and break labels must be adjusted manually for non-linear functions of time. 
+#' @details Plots either a time-interactive hazard ratios, first differences, and relative hazards, or the hazard rates for multiple strata. Currently the strata legend labels need to be changed manually (see \code{\link{revalue}} in the \link{plyr} package) in the \code{simtvc} object with the \code{strata} component. Also, currently the x-axis tick marks and break labels must be adjusted manually for non-linear functions of time. 
 #' Note: A dotted line is created at y = 1 (0 for first difference), i.e. no effect, for time-varying hazard ratio graphs. No line is created for hazard rates.
 #' @examples
 #' ## dontrun
@@ -71,7 +71,7 @@
 #' # Create plots
 #' # simGG(Sim1, legend = FALSE)
 #' # simGG(Sim2)
-#' # simGG(Sim3, leg.name = "Comparision", from = 1200, ribbons = TRUE)
+#' # simGG(Sim3, leg.name = "Comparision", from = 1200, type = 'lines')
 #'
 #' @import ggplot2
 #' @export
@@ -80,13 +80,13 @@
 #'
 #' @references Licht, Amanda A. 2011. ''Change Comes with Time: Substantive Interpretation of Nonproportional Hazards in Event History Analysis.'' Political Analysis 19: 227-43.
 
-simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL, title = NULL, smoother = "auto", spalette = "Set1", legend = "legend", leg.name = "", lsize = 1, psize = 1, alpha = 0.1, ribbons = FALSE, ...)
+simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL, title = NULL, smoother = "auto", spalette = "Set1", legend = "legend", leg.name = "", lsize = 1, psize = 1, alpha = 0.2, type = "points", ...)
 {
-  Time <- HRate <- HRValue <- QI <- Comparison <- Xj <- Lower50 <- Upper50 <- Min <- Max <- Median <- NULL
+  Time <- HRate <- HRValue <- QI <- Comparison <- Xj <- Lower50 <- Upper50 <- Min <- Max <- Median <- SimID <- NULL
   if (!inherits(obj, "simtvc")){
     stop("must be a simtvc object")
   }
-  if (isTRUE(ribbons) & smoother != "auto"){
+  if (type == "ribbons" & smoother != "auto"){
     message("The smoother argument is ignored if ribbons = TRUE. Central tendency summarised with the median.")
   }
 
@@ -101,6 +101,19 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
   }
   # Convert obj to data frame
   class(obj) <- "data.frame"
+
+  # Drop simulations that include outliers
+  if (type == 'lines'){
+      obj <- OutlierDrop(obj)
+  } 
+
+  # Alpha gradient based on percentile in the distribution
+  if (type != 'ribbons' & qi != 'Hazard Rate'){
+    obj <- PercRank(obj, xaxis = 'Time')
+  } else if (type != 'ribbons' & qi == 'Hazard Rate'){
+    obj <- PercRank(obj, xaxis = 'Time', yaxis = 'HRate')
+  }
+
   # Constrict time period to plot for hazard rate  
   if (!is.null(from)){
     obj <- subset(obj, Time >= from)
@@ -110,62 +123,127 @@ simGG.simtvc <- function(obj, from = NULL, to = NULL, xlab = NULL, ylab = NULL,
   }
 
   # Plot points
-  if (!isTRUE(ribbons)){
+  if (type == 'points'){
     if (qi == "Hazard Rate"){
       if (!is.null(obj$Strata)) {
         ggplot(obj, aes(x = Time, y = HRate, colour = factor(HRValue))) +
-          geom_point(alpha = I(alpha), size = psize) +
+          geom_point(aes(alpha = PercRank), size = psize) +
           geom_smooth(method = smoother, size = lsize, se = FALSE) +
           facet_grid(.~ Strata) +
           xlab(xlab) + ylab(ylab) +
           scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+          scale_alpha_continuous(range = c(0, alpha), guide = FALSE) +
           ggtitle(title) +
           #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
       } else if (is.null(obj$Strata)){
           ggplot(obj, aes(Time, HRate, colour = factor(HRValue))) +
-            geom_point(shape = 21, alpha = I(alpha), size = psize) +
+            geom_point(shape = 21, aes(alpha = PercRank), size = psize) +
             geom_smooth(method = smoother, size = lsize, se = FALSE) +
             scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
             xlab(xlab) + ylab(ylab) +
+            scale_alpha_continuous(range = c(0, alpha), guide = FALSE) +
+            ggtitle(title) +
+            #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+            theme_bw(base_size = 15)
+      }
+    } else if (qi == "Hazard Ratio"){
+        ggplot(obj, aes(x = Time, y = QI, colour = factor(Comparison))) +
+          geom_point(aes(alpha = PercRank), size = psize) +
+          geom_smooth(method = smoother, size = lsize, se = FALSE) +
+          geom_hline(aes(yintercept = 1), linetype = "dotted") +
+          xlab(xlab) + ylab(ylab) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+          scale_alpha_continuous(range = c(0, alpha), guide = FALSE) +
+          ggtitle(title) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          theme_bw(base_size = 15)
+    } else if (qi == "Relative Hazard"){
+        ggplot(obj, aes(x = Time, y = QI, colour = factor(Xj))) +
+          geom_point(aes(alpha = PercRank), size = psize) +
+          geom_smooth(method = smoother, size = lsize, se = FALSE) +
+          geom_hline(aes(yintercept = 1), linetype = "dotted") +
+          xlab(xlab) + ylab(ylab) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+          scale_alpha_continuous(range = c(0, alpha), guide = FALSE) +
+          ggtitle(title) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          theme_bw(base_size = 15)
+    } else if (qi == "First Difference"){
+        ggplot(obj, aes(Time, QI, colour = factor(Comparison))) +
+          geom_point(shape = 21, aes(alpha = PercRank), size = psize) +
+          geom_smooth(method = smoother, size = lsize, se = FALSE) +
+          geom_hline(aes(yintercept = 0), linetype = "dotted") +
+          xlab(xlab) + ylab(ylab) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+          scale_alpha_continuous(range = c(0, alpha), guide = FALSE) +
+          ggtitle(title) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1)), colour = FALSE) +
+          theme_bw(base_size = 15)
+    }
+  }
+  # Plot lines
+  else if (type == 'lines'){
+    if (qi == "Hazard Rate"){
+      if (!is.null(obj$Strata)) {
+        ggplot(obj, aes(x = Time, y = HRate, colour = factor(HRValue))) +
+          geom_line(aes(group = interaction(SimID, factor(HRValue)), alpha = PercRank), size = psize) +
+          geom_smooth(aes(colour = factor(HRValue)), method = smoother, size = lsize, se = FALSE) +
+          facet_grid(.~ Strata) +
+          xlab(xlab) + ylab(ylab) +
+          scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+          scale_alpha_continuous(range = c(0, alpha), guide = FALSE) +
+          ggtitle(title) +
+          #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
+          theme_bw(base_size = 15)
+      } else if (is.null(obj$Strata)){
+          ggplot(obj, aes(Time, HRate, colour = factor(HRValue))) +
+            geom_line(aes(group = interaction(SimID, factor(HRValue)), alpha = PercRank), shape = 21, size = psize) +
+            geom_smooth(aes(colour = factor(HRValue)), method = smoother, size = lsize, se = FALSE) +
+            scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+            scale_alpha_continuous(range = c(0, alpha), guide = FALSE) +
+            xlab(xlab) + ylab(ylab) +
             ggtitle(title) +
             #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
             theme_bw(base_size = 15)
       }
     } else if (qi == "Hazard Ratio"){
         ggplot(obj, aes(x = Time, y = QI, colour = factor(Comparison))) +
-          geom_point(alpha = I(alpha), size = psize) +
-          geom_smooth(method = smoother, size = lsize, se = FALSE) +
+          geom_line(aes(group = interaction(SimID, factor(Comparison)), alpha = PercRank), size = psize) +
+              geom_smooth(aes(group = factor(Comparison)), method = smoother, size = lsize, se = FALSE) +
           geom_hline(aes(yintercept = 1), linetype = "dotted") +
           xlab(xlab) + ylab(ylab) +
           scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+          scale_alpha_continuous(range = c(0, alpha), guide = FALSE) +
           ggtitle(title) +
           #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
     } else if (qi == "Relative Hazard"){
         ggplot(obj, aes(x = Time, y = QI, colour = factor(Xj))) +
-          geom_point(alpha = I(alpha), size = psize) +
-          geom_smooth(method = smoother, size = lsize, se = FALSE) +
+          geom_line(aes(group = interaction(SimID, factor(Xj)), alpha = PercRank), size = psize) +
+          geom_smooth(aes(group = factor(Xj)), method = smoother, size = lsize, se = FALSE) +
           geom_hline(aes(yintercept = 1), linetype = "dotted") +
           xlab(xlab) + ylab(ylab) +
           scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+          scale_alpha_continuous(range = c(0, alpha), guide = FALSE) +
           ggtitle(title) +
           #guides(colour = guide_legend(override.aes = list(alpha = 1))) +
           theme_bw(base_size = 15)
     } else if (qi == "First Difference"){
         ggplot(obj, aes(Time, QI, colour = factor(Comparison))) +
-          geom_point(shape = 21, alpha = I(alpha), size = psize) +
-          geom_smooth(method = smoother, size = lsize, se = FALSE) +
+          geom_line(aes(group = interaction(SimID, factor(Comparison)), alpha = PercRank), size = psize) +
+              geom_smooth(aes(group = factor(Comparison)), method = smoother, size = lsize, se = FALSE) +
           geom_hline(aes(yintercept = 0), linetype = "dotted") +
           xlab(xlab) + ylab(ylab) +
           scale_colour_brewer(palette = spalette, name = leg.name, guide = legend) +
+          scale_alpha_continuous(range = c(0, alpha), guide = FALSE) +
           ggtitle(title) +
           #guides(colour = guide_legend(override.aes = list(alpha = 1)), colour = FALSE) +
           theme_bw(base_size = 15)
     }
   }
   # Plot ribbons
-  else if (isTRUE(ribbons)){
+  else if (type == 'ribbons'){
     suppressWarnings(
     if (qi == "Hazard Rate"){
       if (!is.null(obj$Strata)) {
